/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.command;

import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Stream;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.common.command.OzgCloudCommand;
import de.ozgcloud.apilib.common.command.OzgCloudCommandService;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.command.CommandStatus;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;

@Service(ArchiveManagerConfiguration.COMMAND_SERVICE_NAME)
@RequiredArgsConstructor
public class CommandService {

	@Qualifier(ArchiveManagerConfiguration.COMMAND_REMOTE_SERVICE_NAME)
	private final CommandRemoteService remoteService;
	@Qualifier(ArchiveManagerConfiguration.OZGCLOUD_COMMAND_SERVICE_NAME)
	private final OzgCloudCommandService ozgCloudCommandService;

	public Stream<ArchiveManagerCommand> findPending(String vorgangId, String order) {
		return remoteService.findCommands(vorgangId, Optional.of(CommandStatus.PENDING.name()), Optional.of(order));
	}

	public Stream<ArchiveManagerCommand> findFinishedCommands(@NonNull String vorgangId) {
		return remoteService.findCommands(vorgangId, Optional.of(CommandStatus.FINISHED.name()), Optional.empty());
	}

	public boolean hasPendingCommandsExceptWithOrder(String vorgangId, String order) {
		var pendingCommands = ozgCloudCommandService.getPendingCommands(OzgCloudVorgangId.from(vorgangId));
		return pendingCommands.stream().anyMatch(hasNotOrder(order));
	}

	private Predicate<? super OzgCloudCommand> hasNotOrder(String order) {
		return command -> !StringUtils.equals(command.getOrder(), order);
	}
}