/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.historie;

import java.util.Map;
import java.util.Optional;

import de.ozgcloud.archive.common.command.ArchiveManagerCommand;
import de.ozgcloud.archive.common.command.CommandWithPrevious;

class StatusChangeHistoryBuilder extends ChangeHistoryBuilder<StatusChangeHistoryBuilder> {

	static final String GELOESCHT = "Gelöscht";
	static final String ZU_LOESCHEN = "Zu Löschen";
	static final String ABGESCHLOSSEN = "Abgeschlossen";
	static final String BESCHIEDEN = "Beschieden";
	static final String IN_BEARBEITUNG = "In Bearbeitung";
	static final String VERWORFEN = "Verworfen";
	static final String ANGENOMMEN = "Angenommen";
	static final String NEU = "Neu";

	static final Map<String, String> ORDER_TO_STATUS_NAME = Map.of(
			"VORGANG_ANNEHMEN", ANGENOMMEN,
			"VORGANG_VERWERFEN", VERWORFEN,
			"VORGANG_ZURUECKHOLEN", NEU,
			"VORGANG_BEARBEITEN", IN_BEARBEITUNG,
			"VORGANG_BESCHEIDEN", BESCHIEDEN,
			"VORGANG_ABSCHLIESSEN", ABGESCHLOSSEN,
			"VORGANG_ZUM_LOESCHEN_MARKIEREN", ZU_LOESCHEN,
			"VORGANG_WIEDEREROEFFNEN", IN_BEARBEITUNG,
			"VORGANG_LOESCHEN", GELOESCHT,
			"VORGANG_ZURUECKSTELLEN", ANGENOMMEN);

	public static StatusChangeHistoryBuilder builder() {
		return new StatusChangeHistoryBuilder();
	}

	@Override
	boolean isRelevant(ArchiveManagerCommand command) {
		return ORDER_TO_STATUS_NAME.keySet().contains(command.getOrder());
	}

	@Override
	CommandWithChangeValues toCommandWithChangeValues(CommandWithPrevious commandWithPrevious) {
		return new CommandWithChangeValues(commandWithPrevious.getCommand(),
				getStatusBeforeChange(commandWithPrevious),
				getStatusAfterChange(commandWithPrevious));
	}

	String getStatusBeforeChange(CommandWithPrevious commandWithPrevious) {
		return Optional.ofNullable(commandWithPrevious.getPrevious())
				.map(this::getStatus)
				.orElse(NEU);
	}

	String getStatusAfterChange(CommandWithPrevious commandWithPrevious) {
		return getStatus(commandWithPrevious.getCommand());
	}

	String getStatus(ArchiveManagerCommand command) {
		if (!ORDER_TO_STATUS_NAME.containsKey(command.getOrder())) {
			throw new IllegalArgumentException("Unexpected or unknown command order " + command.getOrder());
		}
		return ORDER_TO_STATUS_NAME.get(command.getOrder());
	}
}
