/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.callcontext;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.apilib.common.callcontext.CallContext;

class CallContextProviderTest {

	@Spy
	@InjectMocks
	private CallContextProvider contextProvider;

	@Mock
	private CallContextMapper mapper;
	@Mock
	private CurrentUserService currentUserService;

	@Nested
	class TestProvideContext {

		private final CallContextUser callContextUser = CallContextUserTestFactory.create();

		@BeforeEach
		void mock() {
			when(currentUserService.getUser()).thenReturn(callContextUser);
		}

		@Test
		void shouldGetArchiveCallContextFromGrpcContext() {
			callProvider();

			verify(currentUserService).getUser();
		}

		@Test
		void shouldMapArchiveCallContext() {
			callProvider();

			verify(mapper).toOzgCloudCallContext(callContextUser);
		}

		@Test
		void shouldReturnMappedCallContext() {
			var mappedCallContext = CallContextTestFactory.create();
			when(mapper.toOzgCloudCallContext(callContextUser)).thenReturn(mappedCallContext);

			var context = callProvider();

			assertThat(context).isEqualTo(mappedCallContext);
		}

		private CallContext callProvider() {
			return contextProvider.provideContext();
		}
	}
}
