/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.user;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.user.GrpcOzgCloudUserProfileService;
import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.user.OzgCloudUserProfile;
import de.ozgcloud.apilib.user.OzgCloudUserProfileTestFactory;

class UserServiceTest {

	@InjectMocks
	private UserService service;

	@Mock
	private GrpcOzgCloudUserProfileService grpcService;

	@Mock
	private UserProfileMapper mapper;

	@Nested
	class TestGetById {

		private final OzgCloudUserProfile ozgCloudUserProfile = OzgCloudUserProfileTestFactory.create();

		@Test
		void shouldCallUserProfileService() {
			service.getById(UserProfileTestFactory.USER_ID);

			verify(grpcService).getById(OzgCloudUserId.from(UserProfileTestFactory.USER_ID));
		}

		@Test
		void shouldMap() {
			when(grpcService.getById(OzgCloudUserId.from(UserProfileTestFactory.USER_ID))).thenReturn(ozgCloudUserProfile);

			service.getById(UserProfileTestFactory.USER_ID);

			verify(mapper).fromOzgUserProfile(ozgCloudUserProfile);
		}

		@Test
		void shouldRetrunMappedUserProfile() {
			var mappedUserProfile = UserProfileTestFactory.create();
			when(grpcService.getById(any())).thenReturn(ozgCloudUserProfile);
			when(mapper.fromOzgUserProfile(ozgCloudUserProfile)).thenReturn(mappedUserProfile);

			var userProfile = service.getById(UserProfileTestFactory.USER_ID);

			assertThat(userProfile).contains(mappedUserProfile);
		}

		@Test
		void shouldReturnEmptyForSystemId() {
			var result = service.getById("system-test");

			assertThat(result).isEmpty();
		}

		@Test
		void shoultNOTCallRemoteServiceForSystemId() {
			service.getById("system-test");

			verify(grpcService, never()).getById(any());
		}

	}
}
