package de.ozgcloud.archive.common.xta;

import static org.assertj.core.api.Assertions.*;
import static org.junit.jupiter.api.Assertions.*;

import jakarta.xml.bind.JAXBContext;
import jakarta.xml.bind.Unmarshaller;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.common.test.ReflectionTestUtils;
import de.ozgcloud.xta.client.model.XtaFile;
import de.xoev.xdomea.AbgabeImportBestaetigen0402;
import lombok.SneakyThrows;

class XtaFileReaderTest {

	@Nested
	class TestCreateAbgabeImportBestaetigen0402Reader {

		@Test
		void shouldCreateReader() {
			var reader = XtaFileReader.createAbgabeImportBestaetigen0402Reader();

			assertThat(reader).isExactlyInstanceOf(XtaFileReader.class);
		}

		@Test
		@SneakyThrows
		void shouldSetUnmarshaller() {
			var reader = XtaFileReader.createAbgabeImportBestaetigen0402Reader();

			assertThat(ReflectionTestUtils.getField(reader, "unmarshaller", Unmarshaller.class)).usingRecursiveComparison()
					.isEqualTo(JAXBContext.newInstance(AbgabeImportBestaetigen0402.class).createUnmarshaller());
		}
	}

	@Nested
	class TestRead {

		@Test
		@SneakyThrows
		void shouldReadContent() {
			var reader = XtaFileReader.createAbgabeImportBestaetigen0402Reader();

			var abgabe = reader.read(XtaFileTestFactory.create(AbgabeImportBestaetigen0402TestFactory.FILE_PATH));

			assertThat(abgabe).usingRecursiveComparison().isEqualTo(AbgabeImportBestaetigen0402TestFactory.create());
		}

		@Test
		@SneakyThrows
		void shouldThrowTechnicalException() {
			var reader = XtaFileReader.createAbgabeImportBestaetigen0402Reader();
			XtaFile unknownFile = XtaFileTestFactory.create(XtaFileTestFactory.DUMMY_XML_FILE_PATH);

			assertThrows(TechnicalException.class, () -> reader.read(unknownFile));
		}
	}
}
