/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.kommentar;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import com.google.common.collect.Lists;

import de.ozgcloud.common.binaryfile.FileId;

class AttachmentMapperTest {

	private final AttachmentMapper mapper = Mappers.getMapper(AttachmentMapper.class);

	@Test
	void shouldMapAttachmentsToEmptyList() {
		var attachments = mapper.mapAttachments(null);

		assertThat(attachments).isEmpty();
	}

	@Test
	void shouldMapAttachmentsToList() {
		var attachments = mapper.mapAttachments(Lists.newArrayList("a1", "a2"));

		assertThat(attachments).containsExactly(FileId.from("a1"), FileId.from("a2"));
	}

	@Test
	void shouldMapOneElementToList() {
		var attachments = mapper.mapAttachments("a1");

		assertThat(attachments).containsExactly(FileId.from("a1"));
	}
}
