/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.postfach;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.List;
import java.util.UUID;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.nachrichten.postfach.GrpcFindPostfachMailsRequest;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachMail;
import de.ozgcloud.nachrichten.postfach.PostfachServiceGrpc.PostfachServiceBlockingStub;

class PostfachMailRemoteServiceTest {

	@InjectMocks
	private PostfachMailRemoteService service;
	@Mock
	private PostfachServiceBlockingStub grpcService;
	@Mock
	private PostfachMailMapper postfachNachrichtMapper;

	@Nested
	class TestFindPostfachMails {

		private static final String VORGANG_ID = UUID.randomUUID().toString();

		private final GrpcPostfachMail grpcPostfachMail = GrpcPostfachMailTestFactory.create();
		private final PostfachMail postfachMail = PostfachMailTestFactory.create();

		@BeforeEach
		void init() {
			when(grpcService.findPostfachMails(argThat(this::hasVorgangId)))
					.thenReturn(GrpcPostfachMailTestFactory.createFindPostfachMailsResponse());
			when(postfachNachrichtMapper.toPostfachMail(grpcPostfachMail)).thenReturn(postfachMail);
		}

		@Test
		void shouldGrpcService() {
			callService();

			verify(grpcService).findPostfachMails(argThat(this::hasVorgangId));
		}

		@Test
		void shouldMapToPostfachMail() {
			callService();

			verify(postfachNachrichtMapper).toPostfachMail(grpcPostfachMail);
		}

		@Test
		void shouldReturnPostfachMails() {
			var postfachMails = callService();

			assertThat(postfachMails).containsExactly(postfachMail);
		}

		private boolean hasVorgangId(GrpcFindPostfachMailsRequest request) {
			return VORGANG_ID.equals(request.getVorgangId());
		}

		private List<PostfachMail> callService() {
			return service.findPostfachMails(VORGANG_ID).toList();
		}
	}
}