/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import de.ozgcloud.vorgang.vorgang.GrpcAntragsteller;
import de.ozgcloud.vorgang.vorgang.GrpcEingang;
import de.ozgcloud.vorgang.vorgang.GrpcEingangHeader;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;
import de.ozgcloud.vorgang.vorgang.GrpcZustaendigeStelle;

public class GrpcEingangTestFactory {

	public static final GrpcEingangHeader EINGANG_HEADER = GrpcEingangHeaderTestFactory.create();
	public static final String ID = EingangTestFactory.ID;
	public static final GrpcZustaendigeStelle ZUSTAENDIGE_STELLE = GrpcZustaendigeStelleTestFactory.create();
	public static final GrpcAntragsteller ANTRAGSTELLER = GrpcAntragstellerTestFactory.create();

	public static final GrpcSubForm SUB_FORM = GrpcSubFormTestFactory.create();
	public static final GrpcFormData FORM_DATA = GrpcFormData.newBuilder().addForm(GrpcSubFormTestFactory.create()).build();

	public static GrpcEingang create() {
		return createBuilder().build();
	}

	public static GrpcEingang.Builder createBuilder() {
		return GrpcEingang.newBuilder()
				.setId(ID)
				.setZustaendigeStelle(ZUSTAENDIGE_STELLE)
				.setAntragsteller(ANTRAGSTELLER)
				.setHeader(EINGANG_HEADER)
				.setFormData(FORM_DATA);
	}
}